@@ -70,7 +70,7 @@ pool_compare_models <- function(pobj,
   
   call <- match.call()
   
-  if(class(pobj)!="pmods")
+  if(!inherits(pobj, "pmods"))
     stop("\n", "Object should be of type pmods", "\n")
   if(pobj$model_type=="survival")
     stop("\n", "Methods only available for models of type binomial", "\n")
