@@ -115,7 +115,7 @@ if(is.null(random.eff))
   stop("Random effects not specified")
 if(is.null(method))
   stop("Define selection method: D1, D2, D3 or MPR")
-if (order(unique(data[, impvar]))[1] == 0)
+if (sort(unique(data[, impvar]))[1] == 0)
   stop("Original dataset should not be included")
 if(is.null(nimp))
   stop("Number of imputed datasets is not defined, use nimp!")
